@@ -1,9 +1,9 @@
 package File::Edit::Portable;
-use 5.006;
+use 5.008;
 use strict;
 use warnings;
 
-our $VERSION = '1.08';
+our $VERSION = '1.09';
 
 use Carp;
 use Exporter;
@@ -51,7 +51,7 @@ sub read {
 
         if (! $testing){
             for (@contents){
-                s/[\n\x{0B}\f\r\x{85}]{1,2}|[{utf8}2028-{utf8}2029]]{1,2}//;
+                s/(?:\n|\x{0B}|\f|\r|\x{85}){1,2}//;
             }
         }
         return @contents;
@@ -91,14 +91,14 @@ sub write {
         seek $contents, 0, 0;
 
         while (<$contents>){
-            s/[\n\x{0B}\f\r\x{85}]{1,2}|[{utf8}2028-{utf8}2029]]{1,2}//g;
+            s/(?:\n|\x{0B}|\f|\r|\x{85}){1,2}//g;
             print $wfh $_ . $recsep;
         }
         close $contents;
     }
     else {
         for (@$contents){
-            s/[\n\x{0B}\f\r\x{85}]{1,2}|[{utf8}2028-{utf8}2029]]{1,2}//g;
+            s/(?:\n|\x{0B}|\f|\r|\x{85}){1,2}//g;
             print $wfh $_ . $recsep;
         }
     }
@@ -225,8 +225,7 @@ sub recsep {
     }
 
     seek $fh, 0, 0;
-
-    if (<$fh> =~ /([\n\x{0B}\f\r\x{85}]{1,2}|[{utf8}2028-{utf8}2029]]{1,2})/){
+    if (<$fh> =~ /((?:\n|\x{0B}|\f|\r|\x{85}){1,2})/){
         $self->{recsep} = $1;
     }
 
@@ -266,7 +265,7 @@ sub platform_recsep {
 
     my $fh = $self->_open($file);
 
-    if (<$fh> =~ /([\n\x{0B}\f\r\x{85}]{1,2}|[{utf8}2028-{utf8}2029]]{1,2})/){
+    if (<$fh> =~ /((?:\n|\x{0B}|\f|\r|\x{85}){1,2})/){
         $self->{platform_recsep} = $1;
     }
 
@@ -333,7 +332,7 @@ sub _handle {
         my $platform_recsep = $self->platform_recsep;
 
         while (<$fh>){
-            s/[\n\x{0B}\f\r\x{85}]{1,2}|[{utf8}2028-{utf8}2029]]{1,2}/$platform_recsep/g;
+            s/(?:\n|\x{0B}|\f|\r|\x{85}){1,2}/$platform_recsep/g;
             print $temp_wfh $_;
         }
         
